@@ -6,12 +6,13 @@
 # https://github.com/tsfpga/tsfpga
 # --------------------------------------------------------------------------------------------------
 
-# Standard libraries
-from pathlib import Path
-from typing import TYPE_CHECKING
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Literal
 
 if TYPE_CHECKING:
-    # Local folder libraries
+    from pathlib import Path
+
     from .hdl_file import HdlFile
 
 
@@ -27,37 +28,56 @@ class Constraint:
     def __init__(
         self,
         file: Path,
-        used_in: str = "all",
+        used_in_synthesis: bool = True,
+        used_in_implementation: bool = True,
+        used_in: Literal["all", "synth", "impl"] | None = None,
         scoped_constraint: bool = False,
-        processing_order: str = "normal",
+        processing_order: Literal["early", "normal", "late"] = "normal",
     ) -> None:
         """
         Arguments:
             file: Path to the constraint file. Typically ends in .xdc or .tcl.
-            used_in: Optionally the constraint can be enabled only for "synth" or "impl".
+            used_in_synthesis: Optionally disable the constraint for synthesis.
+            used_in_implementation: Optionally disable the constraint for implementation.
+            used_in: Old way of controlling when the constraint is applied.
+
+                .. deprecated:: 13.1.3
+                    Use the `used_in_synthesis` and `used_in_implementation` arguments instead.
             scoped_constraint: If enabled the constraint file will be loaded with the "-ref"
                 argument in Vivado. An entity with the same name must exist.
             processing_order: Optionally the processing order can be changed to "early" or "late".
         """
         self.file = file
-        self.used_in = used_in
         self.ref = file.stem if scoped_constraint else None
         self.processing_order = processing_order.lower()
 
-        assert self.used_in in ["all", "synth", "impl"], self.used_in
-        assert self.processing_order in ["early", "normal", "late"], self.processing_order
+        if used_in is not None:
+            print(
+                f"DEPRECATED: {self.__class__.__name__}.__init__() argument 'used_in' is "
+                "deprecated and will be removed."
+            )
+            if (not used_in_synthesis) or (not used_in_implementation):
+                raise ValueError("Using both 'used_in_*' and deprecated 'used_in' arguments.")
 
-    def validate_scoped_entity(self, source_files: list["HdlFile"]) -> bool:
+            self.used_in_synthesis = used_in in ("all", "synth")
+            self.used_in_implementation = used_in in ("all", "impl")
+        else:
+            self.used_in_synthesis = used_in_synthesis
+            self.used_in_implementation = used_in_implementation
+
+    def validate_scoped_entity(self, source_files: list[HdlFile]) -> bool:
         """
         Make sure that a matching entity file exists in case this is a scoped constraint.
         The list of source files should be the synthesis files for the module that this
         constraint belongs to.
         """
-        if self.ref is not None:
-            if not any([source_file.path.stem == self.ref] for source_file in source_files):
-                raise FileNotFoundError(
-                    f"Could not find a matching entity file for scoped constraint file {self.file}"
-                )
+        if self.ref is not None and not any(
+            [source_file.path.stem == self.ref] for source_file in source_files
+        ):
+            raise FileNotFoundError(
+                f"Could not find a matching entity file for scoped constraint file {self.file}"
+            )
+
         return True
 
     def __str__(self) -> str:
