@@ -6,20 +6,24 @@
 # https://github.com/tsfpga/tsfpga
 # --------------------------------------------------------------------------------------------------
 
-# Standard libraries
+from __future__ import annotations
+
 from pathlib import Path
+from typing import TYPE_CHECKING, Any
 
-# First party libraries
 from tsfpga.constraint import Constraint
 from tsfpga.examples.example_env import get_hdl_modules, get_tsfpga_example_modules
 from tsfpga.examples.vivado.project import TsfpgaExampleVivadoProject
 from tsfpga.module import BaseModule
 
+if TYPE_CHECKING:
+    from tsfpga.hdl_file import HdlFile
+
 THIS_FILE = Path(__file__)
 
 
 class Module(BaseModule):
-    def get_build_projects(self):
+    def get_build_projects(self) -> list[TsfpgaExampleVivadoProject]:
         projects = []
 
         modules = get_hdl_modules() + get_tsfpga_example_modules()
@@ -77,9 +81,12 @@ class Module(BaseModule):
 
         return projects
 
-    def get_simulation_files(  # type: ignore[override]
-        self, files_avoid=None, include_unisim=True, **kwargs
-    ):  # pylint: disable=arguments-differ
+    def get_simulation_files(
+        self,
+        files_avoid: bool | None = None,
+        include_unisim: bool = True,
+        **kwargs: Any,  # noqa: ANN401
+    ) -> list[HdlFile]:
         """
         Exclude files that depend on IP cores and/or unisim.
 
@@ -87,7 +94,6 @@ class Module(BaseModule):
         point is included in documentation.
         """
         files_to_avoid = {
-            self.path / "src" / "mmcm_wrapper.vhd",
             self.path / "src" / "artyz7_top.vhd",
             self.path / "test" / "tb_artyz7_top.vhd",
         }
