@@ -6,11 +6,9 @@
 # https://github.com/tsfpga/tsfpga
 # --------------------------------------------------------------------------------------------------
 
-# Standard libraries
 from pathlib import Path
 from typing import Any
 
-# First party libraries
 from tsfpga.vivado.project import VivadoNetlistProject, VivadoProject
 
 THIS_DIR = Path(__file__).parent
@@ -22,15 +20,16 @@ class TsfpgaExampleVivadoProject(VivadoProject):
     Shows how to override and extend the base behavior.
     """
 
-    def pre_create(  # type: ignore[override]  # pylint: disable=arguments-differ
-        self, generics: dict[str, Any], **kwargs: Any
+    def pre_create(
+        self,
+        generics: dict[str, Any],
+        **kwargs: Any,  # noqa: ANN401
     ) -> bool:
         """
         Override parent method to add custom behavior.
         Update TCL sources just before project creation.
         """
         self.tcl_sources.append(THIS_DIR / "tcl" / "example_vivado_messages.tcl")
-        self.tcl_sources.append(THIS_DIR / "tcl" / "example_vivado_message_undriven_pin.tcl")
 
         return super().pre_create(generics=generics, kwargs=kwargs)
 
@@ -41,15 +40,16 @@ class TsfpgaExampleVivadoNetlistProject(VivadoNetlistProject):
     Shows how to override and extend the base behavior.
     """
 
-    def pre_create(  # type: ignore[override]  # pylint: disable=arguments-differ
-        self, generics: dict[str, Any], **kwargs: Any
+    def pre_create(
+        self,
+        generics: dict[str, Any],
+        **kwargs: Any,  # noqa: ANN401
     ) -> bool:
         """
         Override parent method to add custom behavior.
         Update TCL sources just before project creation.
         """
         self.tcl_sources.append(THIS_DIR / "tcl" / "example_vivado_messages.tcl")
-        self.tcl_sources.append(THIS_DIR / "tcl" / "example_vivado_message_undriven_pin.tcl")
         self.tcl_sources.append(THIS_DIR / "tcl" / "example_vivado_netlist_messages.tcl")
 
         return super().pre_create(generics=generics, kwargs=kwargs)
