@@ -24,22 +24,20 @@ puts "Applying example vivado message rules"
 set_msg_config -new_severity "ERROR" -id "Synth 8-5863"
 set_msg_config -new_severity "ERROR" -id "Synth 8-327"
 
-# Message: Terminal has IOB constraint set to TRUE, but it is either not
-#     connected to a FLOP element or the connected FLOP element could not be brought into the I/O.
-# Motivation: This warning appears only if we have specifically instructed the tool to use IOB,
-#     in which case failure to achieve that is an error.
-set_msg_config -new_severity "ERROR" -id "Place 30-722"
+# Message: Tying undriven pin to a constant.
+# Motivation: An undriven pin that is used, is probably a mistake in the code.
+set_msg_config -new_severity "ERROR" -id "Synth 8-3295"
 
 # Couple of messages related to multi-driver nets or pins.
 # Motivation: Driving from multiple sources is in most cases a mistake in the code.
 #     We do our best to avoid this already by always using unresolved types.
 #     Perhaps there is a use case out there in some exotic design, hence we keep the message raise
-#     of this here in the example.
+#     here in the example and not in the main file.
 set_msg_config -new_severity "ERROR" -id "Opt 31-80"
 set_msg_config -new_severity "ERROR" -id "Route 35-14"
 set_msg_config -new_severity "ERROR" -id "Synth 8-6859"
 set_msg_config -new_severity "ERROR" -id "Synth 8-3352"
-set_property SEVERITY "ERROR" [get_drc_checks "MDRV-1"]
+set_property "SEVERITY" "ERROR" [get_drc_checks "MDRV-1"]
 
 # Message: Case statement has an input that will never be executed.
 # Motivation: Probably caused by a mistake in the code.
@@ -80,7 +78,7 @@ set_msg_config -new_severity "ERROR" -id "Vivado 12-1411"
 
 # Message: MMCM or PLL VCO frequency out of range.
 # Motivation: Design will not work as intended when this is the case.
-set_property SEVERITY "ERROR" [get_drc_checks "AVAL-46"]
+set_property "SEVERITY" "ERROR" [get_drc_checks "AVAL-46"]
 
 # Message: Syntax error.
 # Motivation: Quite a general message, but it definitely implies an error.
