@@ -6,7 +6,8 @@
 # https://github.com/tsfpga/tsfpga
 # --------------------------------------------------------------------------------------------------
 
-# Standard libraries
+from __future__ import annotations
+
 import importlib.util
 import os
 import subprocess
@@ -14,13 +15,16 @@ from os.path import commonpath, relpath
 from pathlib import Path
 from platform import system
 from shutil import rmtree
-from typing import Any, Optional
+from sys import modules
+from typing import TYPE_CHECKING
 
-# First party libraries
 from tsfpga import DEFAULT_FILE_ENCODING
 
+if TYPE_CHECKING:
+    from types import ModuleType
 
-def create_file(file: Path, contents: Optional[str] = None) -> Path:
+
+def create_file(file: Path, contents: str | None = None) -> Path:
     """
     Create the ``file`` and any parent directories that do not exist.
     File will be empty unless ``contents`` is specified.
@@ -28,11 +32,11 @@ def create_file(file: Path, contents: Optional[str] = None) -> Path:
     Return:
         The path to the file that was created (i.e. the original ``file`` argument).
     """
-    # Create directory unless it already exists. Do not delete anything if it exists.
+    # Create directory unless it already exists. Do not delete anything if it does exist.
     create_directory(directory=file.parent, empty=False)
 
     contents = "" if contents is None else contents
-    with open(file, "w", encoding=DEFAULT_FILE_ENCODING) as file_handle:
+    with file.open("w", encoding=DEFAULT_FILE_ENCODING) as file_handle:
         file_handle.write(contents)
 
     return file
@@ -42,7 +46,7 @@ def read_file(file: Path) -> str:
     """
     Read and return the file contents.
     """
-    with open(file, encoding=DEFAULT_FILE_ENCODING) as file_handle:
+    with file.open(encoding=DEFAULT_FILE_ENCODING) as file_handle:
         return file_handle.read()
 
 
@@ -61,7 +65,7 @@ def read_last_lines_of_file(file: Path, num_lines: int) -> str:
     result_lines: list[str] = []
     blocks_to_read = 0
 
-    with open(file, encoding=DEFAULT_FILE_ENCODING) as file_handle:
+    with file.open(encoding=DEFAULT_FILE_ENCODING) as file_handle:
         while len(result_lines) < num_lines:
             # Since we do not know the line lengths, there is some guessing involved. Keep reading
             # larger and larger blocks until we have all the lines that are requested.
@@ -70,7 +74,7 @@ def read_last_lines_of_file(file: Path, num_lines: int) -> str:
             try:
                 # Read a block from the end
                 file_handle.seek(-blocks_to_read * 4096, os.SEEK_END)
-            except IOError:
+            except OSError:
                 # Tried to read more data than what is available. Read whatever we have and return
                 # to user.
                 file_handle.seek(0)
@@ -79,8 +83,22 @@ def read_last_lines_of_file(file: Path, num_lines: int) -> str:
 
             result_lines = file_handle.readlines()
 
-    result = "".join(result_lines[-num_lines:])
-    return result
+    return "".join(result_lines[-num_lines:])
+
+
+def prepend_file(file_path: Path, text: str) -> Path:
+    """
+    Insert the ``text`` at the beginning of the file, before any existing content.
+
+    Returns:
+        The original file path.
+    """
+    with file_path.open("r+") as file_handle:
+        existing_content = file_handle.read()
+        file_handle.seek(0)
+        file_handle.write(text + existing_content)
+
+    return file_path
 
 
 def delete(path: Path, wait_until_deleted: bool = False) -> Path:
@@ -118,15 +136,21 @@ def create_directory(directory: Path, empty: bool = True) -> Path:
         directory: Path to the directory.
         empty: If true and the directory already exists, all existing files/folders in it will
             be deleted.
-            If false, this function will do nothing, since the directory already exists.
+            If false, the directory will be left as-is if it already exists, or will be newly
+            created if it does not.
 
     Return:
         The path that was created (i.e. the original ``directory`` argument).
     """
     if empty:
+        # Delete directory, and anything inside it, before creating it below.
         delete(directory)
+
     elif directory.exists():
-        return directory
+        if directory.is_dir():
+            return directory
+
+        raise FileExistsError(f"Requested directory path already exists as a file: {directory}")
 
     directory.mkdir(parents=True)
     return directory
@@ -158,14 +182,13 @@ def path_relative_to(path: Path, other: Path) -> Path:
     Note Path.relative_to() does not support the use case where e.g. readme.md should get
     relative path "../readme.md". Hence we have to use os.path.
     """
-    assert path.exists(), path
     return Path(relpath(str(path), str(other)))
 
 
 def run_command(
     cmd: list[str],
-    cwd: Optional[Path] = None,
-    env: Optional[dict[str, str]] = None,
+    cwd: Path | None = None,
+    env: dict[str, str] | None = None,
     capture_output: bool = False,
 ) -> subprocess.CompletedProcess[str]:
     """
@@ -183,7 +206,7 @@ def run_command(
         be inspected.
     """
     if not isinstance(cmd, list):
-        raise ValueError("Must be called with a list, not a string")
+        raise TypeError("Must be called with a list, not a string")
 
     return subprocess.run(
         args=cmd,
@@ -195,7 +218,7 @@ def run_command(
     )
 
 
-def load_python_module(file: Path) -> Any:
+def load_python_module(file: Path) -> ModuleType:
     """
     Load the specified Python module.
     Note that in Python nomenclature, a module is a source code file.
@@ -209,6 +232,7 @@ def load_python_module(file: Path) -> Any:
         raise RuntimeError(f"Could not load the Python module: {file}")
 
     module = importlib.util.module_from_spec(spec=spec)
+    modules[python_module_name] = module
     spec.loader.exec_module(module=module)
 
     return module
