@@ -6,24 +6,27 @@
 # https://github.com/tsfpga/tsfpga
 # --------------------------------------------------------------------------------------------------
 
-# Standard libraries
+from __future__ import annotations
+
 from pathlib import Path
-from typing import Any, Optional
+from typing import TYPE_CHECKING, ClassVar
 
-# First party libraries
 from tsfpga.system_utils import create_file
 
-# Local folder libraries
 from .common import run_vivado_tcl, to_tcl_path
 from .simlib_common import VivadoSimlibCommon
 
+if TYPE_CHECKING:
+    from vunit.sim_if import SimulatorInterface
+    from vunit.ui import VUnit
+
 
 class VivadoSimlibCommercial(VivadoSimlibCommon):
     """
     Handle Vivado simlib with a commercial simulator.
     """
 
-    library_names = ["unisim", "secureip", "unimacro", "unifast", "xpm"]
+    library_names: ClassVar = ["unisim", "secureip", "unimacro", "unifast", "xpm"]
 
     _tcl = (
         "set_param general.maxthreads 8\n"
@@ -41,11 +44,11 @@ class VivadoSimlibCommercial(VivadoSimlibCommon):
 
     def __init__(
         self,
-        vivado_path: Optional[Path],
+        vivado_path: Path | None,
         output_path: Path,
-        vunit_proj: Any,
-        simulator_interface: Any,
-    ):
+        vunit_proj: VUnit,
+        simulator_interface: SimulatorInterface,
+    ) -> None:
         """
         Arguments:
             output_path: The compiled simlib will be placed here.
@@ -60,7 +63,7 @@ class VivadoSimlibCommercial(VivadoSimlibCommon):
 
         self._vunit_proj = vunit_proj
 
-    def _get_simulator_name(self, simulator_interface: Any) -> str:
+    def _get_simulator_name(self, simulator_interface: SimulatorInterface) -> str:
         """
         Used to get the "-simulator" argument to the Vivado "compile_simlib" function.
         In some cases Vivado needs a different simulator name than what is used in VUnit.
@@ -78,7 +81,6 @@ class VivadoSimlibCommercial(VivadoSimlibCommon):
         # Siemens Questa is called "modelsim" in VUnit but Vivado needs the name "questasim".
         # See discussion in
         #   https://github.com/VUnit/vunit/issues/834
-        #   https://gitlab.com/tsfpga/tsfpga/-/issues/67
         # Use the simulator installation path to decode whether we are running Questa or
         # regular ModelSim.
         if "questa" in str(self._simulator_folder).lower():
@@ -86,7 +88,7 @@ class VivadoSimlibCommercial(VivadoSimlibCommon):
 
         # In other cases Vivado uses the same name as VUnit.
         # We do not do typing of the 'simulator_interface', but we know that '.name' is a string.
-        return simulator_interface.name  # type: ignore[no-any-return]
+        return simulator_interface.name
 
     def _compile(self) -> None:
         tcl_file = self.output_path / "compile_simlib.tcl"
@@ -114,6 +116,7 @@ class VivadoSimlibCommercial(VivadoSimlibCommon):
         """
         for library_name in self.library_names:
             library_path = self.output_path / library_name
-            assert library_path.exists(), library_path
+            if not library_path.exists():
+                raise FileNotFoundError(f"Library path not found: {library_path}")
 
             self._vunit_proj.add_external_library(library_name, library_path)
