@@ -6,13 +6,10 @@
 # https://github.com/tsfpga/tsfpga
 # --------------------------------------------------------------------------------------------------
 
-# Standard libraries
 from unittest.mock import MagicMock, patch
 
-# Third party libraries
 import pytest
 
-# First party libraries
 from tsfpga.ip_core_file import IpCoreFile
 from tsfpga.module import BaseModule, get_modules
 from tsfpga.system_utils import create_file, delete
@@ -34,7 +31,7 @@ def test_system_call_to_vivado_failing_should_raise_exception(tmp_path):
     with patch("tsfpga.vivado.ip_cores.VivadoIpCoreProject.create", autospec=True) as create:
         create.return_value = False
 
-        with pytest.raises(AssertionError) as exception_info:
+        with pytest.raises(RuntimeError) as exception_info:
             project.create_vivado_project_if_needed()
 
         assert str(exception_info.value) == "Failed to create Vivado IP core project"
@@ -52,11 +49,11 @@ def ip_cores_test(tmp_path):
                 self.modules_folder / "hest" / "ip_cores" / "hest.tcl", "hest"
             )
 
-            modules = get_modules([self.modules_folder])
+            modules = get_modules(self.modules_folder)
             self.vivado_ip_cores = VivadoIpCores(modules, self.project_folder, part_name="-")
 
             # Create initial hash and (empty) compile order file
-            self.vivado_ip_cores._save_hash()  # pylint: disable=protected-access
+            self.vivado_ip_cores._save_hash()  # noqa: SLF001
             self.create_compile_order_file()
 
         def create_compile_order_file(self):
@@ -65,10 +62,6 @@ def ip_cores_test(tmp_path):
     return IpCoresTest()
 
 
-# False positive for pytest fixtures
-# pylint: disable=redefined-outer-name
-
-
 @patch("tsfpga.vivado.ip_cores.VivadoIpCoreProject.create", autospec=True)
 def test_should_not_recreate(create, ip_cores_test):
     assert not ip_cores_test.vivado_ip_cores.create_vivado_project_if_needed()
@@ -84,7 +77,7 @@ def test_should_recreate_if_compile_order_file_is_missing(create, ip_cores_test)
 
 @patch("tsfpga.vivado.ip_cores.VivadoIpCoreProject.create", autospec=True)
 def test_should_recreate_if_hash_file_is_missing(create, ip_cores_test):
-    delete(ip_cores_test.vivado_ip_cores._hash_file)  # pylint: disable=protected-access
+    delete(ip_cores_test.vivado_ip_cores._hash_file)  # noqa: SLF001
     assert ip_cores_test.vivado_ip_cores.create_vivado_project_if_needed()
     create.assert_called_once()
 
@@ -94,7 +87,7 @@ def test_should_not_recreate_if_nothing_is_changed(create, ip_cores_test):
     # This test shows that the pattern used in the upcoming tests:
     #   change something -> get modules -> create new VivadoIpCores object
     # should not result in a recreate unless we actually change something.
-    modules = get_modules([ip_cores_test.modules_folder])
+    modules = get_modules(ip_cores_test.modules_folder)
     vivado_ip_cores = VivadoIpCores(modules, ip_cores_test.project_folder, part_name="-")
 
     assert not vivado_ip_cores.create_vivado_project_if_needed()
@@ -104,7 +97,7 @@ def test_should_not_recreate_if_nothing_is_changed(create, ip_cores_test):
 @patch("tsfpga.vivado.ip_cores.VivadoIpCoreProject.create", autospec=True)
 def test_should_recreate_if_ip_core_file_is_added(create, ip_cores_test):
     create_file(ip_cores_test.modules_folder / "zebra" / "ip_cores" / "zebra.tcl", "zebra")
-    modules = get_modules([ip_cores_test.modules_folder])
+    modules = get_modules(ip_cores_test.modules_folder)
     vivado_ip_cores = VivadoIpCores(modules, ip_cores_test.project_folder, part_name="-")
 
     assert vivado_ip_cores.create_vivado_project_if_needed()
@@ -114,7 +107,7 @@ def test_should_recreate_if_ip_core_file_is_added(create, ip_cores_test):
 @patch("tsfpga.vivado.ip_cores.VivadoIpCoreProject.create", autospec=True)
 def test_should_recreate_if_ip_core_file_is_removed(create, ip_cores_test):
     delete(ip_cores_test.hest_tcl)
-    modules = get_modules([ip_cores_test.modules_folder])
+    modules = get_modules(ip_cores_test.modules_folder)
     vivado_ip_cores = VivadoIpCores(modules, ip_cores_test.project_folder, part_name="-")
 
     assert vivado_ip_cores.create_vivado_project_if_needed()
@@ -124,7 +117,7 @@ def test_should_recreate_if_ip_core_file_is_removed(create, ip_cores_test):
 @patch("tsfpga.vivado.ip_cores.VivadoIpCoreProject.create", autospec=True)
 def test_should_recreate_if_ip_core_file_is_changed(create, ip_cores_test):
     create_file(ip_cores_test.apa_tcl, "blaha blaha")
-    modules = get_modules([ip_cores_test.modules_folder])
+    modules = get_modules(ip_cores_test.modules_folder)
     vivado_ip_cores = VivadoIpCores(modules, ip_cores_test.project_folder, part_name="-")
 
     assert vivado_ip_cores.create_vivado_project_if_needed()
