@@ -6,21 +6,17 @@
 # https://github.com/tsfpga/tsfpga
 # --------------------------------------------------------------------------------------------------
 
-# Standard libraries
 from collections import OrderedDict
 from pathlib import Path
 from unittest.mock import MagicMock
 
-# Third party libraries
 import pytest
 
-# First party libraries
 from tsfpga.build_step_tcl_hook import BuildStepTclHook
+from tsfpga.constraint import Constraint
 from tsfpga.ip_core_file import IpCoreFile
 from tsfpga.module import BaseModule, get_modules
 from tsfpga.system_utils import create_file
-
-# pylint: disable=unused-import
 from tsfpga.test.test_utils import file_contains_string
 from tsfpga.vivado.common import to_tcl_path
 from tsfpga.vivado.generics import BitVectorGenericValue, StringGenericValue
@@ -29,7 +25,7 @@ from tsfpga.vivado.tcl import VivadoTcl
 
 def test_set_create_run_index():
     tcl = VivadoTcl(name="").create(project_folder=Path(), modules=[], part="", top="", run_index=2)
-    assert "\ncurrent_run [get_runs synth_2]\n" in tcl
+    assert '\ncurrent_run [get_runs "synth_2"]\n' in tcl
 
 
 def test_static_generics():
@@ -47,7 +43,8 @@ def test_static_generics():
         project_folder=Path(), modules=[], part="", top="", run_index=1, generics=generics
     )
     expected = (
-        "\nset_property generic {enable=1'b1 disable=1'b0 integer=123 slv=4'b0101 string=\"apa\"} "
+        '\nset_property "generic" '
+        "{enable=1'b1 disable=1'b0 integer=123 slv=4'b0101 string=\"apa\"} "
         "[current_fileset]\n"
     )
     assert expected in tcl
@@ -66,13 +63,13 @@ def test_build_step_hooks():
     )
 
     assert (
-        f"\nset_property STEPS.SYNTH_DESIGN.TCL.PRE {{{to_tcl_path(dummy.tcl_file)}}} ${{run}}\n"
-        in tcl
-    )
+        f"\n  "
+        f'set_property "STEPS.SYNTH_DESIGN.TCL.PRE" {{{to_tcl_path(dummy.tcl_file)}}} ${{run}}\n'
+    ) in tcl
     assert (
-        f"\nset_property STEPS.ROUTE_DESIGN.TCL.PRE {{{to_tcl_path(files.tcl_file)}}} ${{run}}\n"
-        in tcl
-    )
+        f"\n  "
+        f'set_property "STEPS.ROUTE_DESIGN.TCL.PRE" {{{to_tcl_path(files.tcl_file)}}} ${{run}}\n'
+    ) in tcl
 
 
 def test_build_step_hooks_with_same_hook_step(tmp_path):
@@ -93,7 +90,8 @@ def test_build_step_hooks_with_same_hook_step(tmp_path):
     assert file_contains_string(hook_file, f"source {{{to_tcl_path(files.tcl_file)}}}")
 
     assert (
-        f"\nset_property STEPS.SYNTH_DESIGN.TCL.PRE {{{to_tcl_path(hook_file)}}} ${{run}}\n" in tcl
+        f'\n  set_property "STEPS.SYNTH_DESIGN.TCL.PRE" {{{to_tcl_path(hook_file)}}} ${{run}}\n'
+        in tcl
     )
 
 
@@ -114,9 +112,8 @@ def test_multiple_threads_is_capped_by_vivado_limits():
     tcl = VivadoTcl(name="").build(
         project_file=Path(), output_path=Path(), num_threads=num_threads, run_index=1
     )
-    print(tcl)
-    assert "set_param general.maxThreads 32" in tcl
-    assert "set_param synth.maxThreads 8" in tcl
+    assert 'set_param "general.maxThreads" 32' in tcl
+    assert 'set_param "synth.maxThreads" 8' in tcl
     assert "launch_runs ${run} -jobs 128" in tcl
     assert "launch_runs ${run} -jobs 128" in tcl
 
@@ -145,9 +142,9 @@ def test_runtime_generics():
         output_path=Path(),
         num_threads=0,
         run_index=0,
-        generics=dict(dummy=True),
+        generics={"dummy": True},
     )
-    expected = "\nset_property generic {dummy=1'b1} [current_fileset]\n"
+    expected = '\nset_property "generic" {dummy=1\'b1} [current_fileset]\n'
     assert expected in tcl
 
 
@@ -187,7 +184,7 @@ def test_module_getters_are_called_with_correct_arguments():
         part="",
         top="",
         run_index=1,
-        other_arguments=dict(apa=123, hest=456),
+        other_arguments={"apa": 123, "hest": 456},
     )
 
     modules[0].get_synthesis_files.assert_called_once_with(apa=123, hest=456)
@@ -197,7 +194,7 @@ def test_module_getters_are_called_with_correct_arguments():
 
 @pytest.fixture
 def vivado_tcl_test(tmp_path):
-    class VivadoTclTest:  # pylint: disable=too-many-instance-attributes
+    class VivadoTclTest:
         def __init__(self):
             self.modules_folder = tmp_path / "modules"
 
@@ -223,17 +220,13 @@ def vivado_tcl_test(tmp_path):
             # A library with only test files
             self.d_vhd = to_tcl_path(create_file(self.modules_folder / "zebra" / "test" / "d.vhd"))
 
-            self.modules = get_modules([self.modules_folder])
+            self.modules = get_modules(self.modules_folder)
 
             self.tcl = VivadoTcl(name="name")
 
     return VivadoTclTest()
 
 
-# False positive for pytest fixtures
-# pylint: disable=redefined-outer-name
-
-
 def test_source_file_list_is_correctly_formatted(vivado_tcl_test):
     tcl = vivado_tcl_test.tcl.create(
         project_folder=Path(), modules=vivado_tcl_test.modules, part="", top="", run_index=1
@@ -241,11 +234,11 @@ def test_source_file_list_is_correctly_formatted(vivado_tcl_test):
 
     # Order of files is not really deterministic
     expected_1 = (
-        "\nread_vhdl -library apa -vhdl2008 "
+        '\nread_vhdl -library "apa" -vhdl2008 '
         f"{{{{{vivado_tcl_test.b_vhd}}} {{{vivado_tcl_test.a_vhd}}}}}\n"
     )
     expected_2 = (
-        "\nread_vhdl -library apa -vhdl2008 "
+        '\nread_vhdl -library "apa" -vhdl2008 '
         f"{{{{{vivado_tcl_test.a_vhd}}} {{{vivado_tcl_test.b_vhd}}}}}\n"
     )
     assert expected_1 in tcl or expected_2 in tcl
@@ -258,19 +251,51 @@ def test_only_synthesis_files_added_to_create_project_tcl(vivado_tcl_test):
     tcl = vivado_tcl_test.tcl.create(
         project_folder=Path(), modules=vivado_tcl_test.modules, part="", top="", run_index=1
     )
-    assert vivado_tcl_test.a_vhd in tcl and vivado_tcl_test.c_v in tcl
-    assert vivado_tcl_test.tb_a_vhd not in tcl and "tb_a.vhd" not in tcl
+    assert vivado_tcl_test.a_vhd in tcl
+    assert vivado_tcl_test.c_v in tcl
+    assert vivado_tcl_test.tb_a_vhd not in tcl
+    assert "tb_a.vhd" not in tcl
 
 
 def test_constraints(vivado_tcl_test):
+    constraint_folder = vivado_tcl_test.modules[0].path.parent.resolve() / "z" / "tcl"
+
     tcl = vivado_tcl_test.tcl.create(
-        project_folder=Path(), modules=vivado_tcl_test.modules, part="part", top="", run_index=1
+        project_folder=Path(),
+        modules=vivado_tcl_test.modules,
+        part="part",
+        top="",
+        run_index=1,
+        constraints=[
+            Constraint(constraint_folder / "x.xdc"),
+            Constraint(constraint_folder / "y.tcl", used_in_synthesis=False),
+            Constraint(
+                constraint_folder / "z.xdc", used_in_implementation=False, processing_order="early"
+            ),
+        ],
     )
 
-    expected = f"\nread_xdc -ref a {{{vivado_tcl_test.a_xdc}}}\n"
-    assert expected in tcl
-    expected = f"\nread_xdc -ref b -unmanaged {{{vivado_tcl_test.b_tcl}}}\n"
-    assert expected in tcl
+    # Scoped constraints from the modules.
+    assert f'\nread_xdc -ref "a" {{{vivado_tcl_test.a_xdc}}}\n' in tcl
+    assert f'\nread_xdc -ref "b" -unmanaged {{{vivado_tcl_test.b_tcl}}}\n' in tcl
+
+    # Regular constraints
+    constraint_file = to_tcl_path(constraint_folder / "x.xdc")
+    assert f"\nread_xdc {{{constraint_file}}}\n" in tcl
+    assert f'"PROCESSING_ORDER" "NORMAL" [get_files {{{constraint_file}}}' in tcl
+    assert f"false [get_files {{{constraint_file}}}" not in tcl
+
+    constraint_file = to_tcl_path(constraint_folder / "y.tcl")
+    assert f"\nread_xdc -unmanaged {{{constraint_file}}}\n" in tcl
+    assert f'"PROCESSING_ORDER" "NORMAL" [get_files {{{constraint_file}}}' in tcl
+    assert f'"USED_IN_SYNTHESIS" false [get_files {{{constraint_file}}}' in tcl
+    assert f'"USED_IN_IMPLEMENTATION" false [get_files {{{constraint_file}}}' not in tcl
+
+    constraint_file = to_tcl_path(constraint_folder / "z.xdc")
+    assert f"\nread_xdc {{{constraint_file}}}\n" in tcl
+    assert f'"PROCESSING_ORDER" "EARLY" [get_files {{{constraint_file}}}' in tcl
+    assert f'"USED_IN_SYNTHESIS" false [get_files {{{constraint_file}}}' not in tcl
+    assert f'"USED_IN_IMPLEMENTATION" false [get_files {{{constraint_file}}}' in tcl
 
 
 def test_ip_core_files(vivado_tcl_test):
@@ -355,8 +380,8 @@ def test_io_buffer_setting(vivado_tcl_test):
     )
 
     no_io_buffers_tcl = (
-        "\nset_property -name {STEPS.SYNTH_DESIGN.ARGS.MORE OPTIONS} "
-        "-value -no_iobuf -objects [get_runs synth_1]\n"
+        '\nset_property -name "STEPS.SYNTH_DESIGN.ARGS.MORE OPTIONS" '
+        '-value "-no_iobuf" -objects [get_runs "synth_1"]\n'
     )
     assert no_io_buffers_tcl in tcl
 
@@ -406,8 +431,15 @@ def test_impl_explore(vivado_tcl_test):
         impl_explore=True,
     )
 
-    assert f"launch_runs -jobs {num_runs} [get_runs impl_explore_*] -to_step write_bitstream" in tcl
-    assert "wait_on_runs -exit_condition ANY_ONE_MET_TIMING [get_runs impl_explore_*]" in tcl
+    assert (
+        f'launch_runs -jobs {num_runs} [get_runs "impl_explore_*"] -to_step "write_bitstream"'
+        in tcl
+    )
+    assert (
+        'wait_on_runs -quiet -exit_condition ANY_ONE_MET_TIMING [get_runs "impl_explore_*"]' in tcl
+    )
     assert 'reset_runs [get_runs -filter {STATUS == "Queued..."}]' in tcl
-    assert 'wait_on_runs [get_runs -filter {STATUS != "Not started"} impl_explore_*]' in tcl
-    assert 'foreach run [get_runs -filter {PROGRESS == "100%"} impl_explore_*]' in tcl
+    assert (
+        'wait_on_runs -quiet [get_runs -filter {STATUS != "Not started"} "impl_explore_*"]' in tcl
+    )
+    assert 'foreach run [get_runs -filter {PROGRESS == "100%"} "impl_explore_*"]' in tcl
